pub type RecvSession = Session<RecvStream>;Expand description
Session type used for receiving streams
Aliased Type
pub struct RecvSession { /* private fields */ }Implementations
Sourceimpl RecvSession
impl RecvSession
Sourcepub fn set_roc(&mut self, ssrc: u32, roc: u32) -> Result<(), SrtpError>
pub fn set_roc(&mut self, ssrc: u32, roc: u32) -> Result<(), SrtpError>
set the ROC on a specific stream
Used for late joiners to a multicasted stream. This function is usually called just after the stream is added otherwise unprotect will fail.
The ROC is confirmed in the stream after the next successfull unprotect operation
The given ROC must be lower or equal than the current one (which should be 0 if this is called just after the stream is added to the session)
Arguments
- ssrc: the ssrc identifying the stream
- roc: the roc value
Returns Ok or
- StreamNotFound: no stream matching this SSRC in the session
- InvalidPacketIndex: given ROC < current ROC